Struct linux_taskstats::Memory [−][src]
pub struct Memory {
pub rss_total: u64,
pub virt_total: u64,
pub minor_faults: u64,
pub major_faults: u64,
}Expand description
Statistics related to memory, vm
Fields
rss_total: u64Accumulated RSS usage in duration of a task, in MBytes-usecs
virt_total: u64Accumulated virtual memory usage in duration of a task
minor_faults: u64Minor faults count
major_faults: u64Major faults count